@@ -24,7 +24,7 @@ syntax_parser = NewsSyntaxParser(emb)
 gensim_emb = None
 
 
-with open(os.path.join(os.path.dirname(__file__), '..', 'models', 'natasha_projector.pkl'), 'rb') as f:
+with open(os.path.join(os.path.dirname(__file__), 'models', 'natasha_projector.pkl'), 'rb') as f:
     projector = pickle.load(f)
 
 
